Takes a newly drawn flowline and uses the dem to ensure the flowline is digitized in the upstream direction.
flowline(flowline, reach_name, dem)a valid flowline sf object
Uses orient_lines_from_dem() for endpoint-based upstream orientation. If direction cannot be resolved, returns unchanged linework with a warning.