R/survey_acquisition_groups.R
propose_survey_acquisition_groups.RdPropose acquisition months from retained provider evidence
propose_survey_acquisition_groups(discovery)One row per selected collection, preserving date evidence and a proposed month only for complete, ordered dates in one calendar month.