Creates a valid set of cross section features from newly digitized stream cross section lines.
cross_section(
xs,
flowline_points,
watershed = c("required", "optional", "skip")
)sf object; A newly digitized set of cross sections.
sf object; A flowline_points feature.
character; Controls upstream watershed lookup. `"required"` preserves strict behavior and stops when the remote watershed service fails. `"optional"` returns missing watershed area with a warning when lookup fails. `"skip"` does not call the watershed service and returns missing watershed area.
an sf object representing a valid set of cross section line features